@@ -3,7 +3,6 @@
 
 import datetime
 from pageone import PageOne
-from particle import Particle 
 
 import lauteur
 from siegfried import (
@@ -269,16 +268,16 @@ class SupeRSS:
     f = feedparser.parse(self.feed)
     return self.run_concurrent(self.parse_entry, f.entries)
 
-  def run_non_full_text(self):
-    """
-    Parse feed, extract article test, merge
-    """
-    return self.run_concurrent(self.extract_and_merge, self.run_full_text())
+  # def run_non_full_text(self):
+  #   """
+  #   Parse feed, extract article test, merge
+  #   """
+  #   return self.run_concurrent(self.extract_and_merge, self.run_full_text())
 
-  def run_homepage(self):
-    pg1 = PageOne(url=self.homepage)
-    pt = Particle()
-    return self.run_concurrent(pt.extract, pg1.articles())
+  # def run_homepage(self):
+  #   pg1 = PageOne(url=self.homepage)
+  #   pt = Particle()
+  #   return self.run_concurrent(pt.extract, pg1.articles())
 
   def run(self):
     """
